pub fn open_stream(url: &str) -> Result<StreamingReader>Expand description
Start streaming url in a background thread and return a reader that
blocks only when the read position overtakes the download.
Returns after PREBUFFER_BYTES have been buffered (or the download
completes, whichever comes first).